@@ -6,7 +6,7 @@ from pandas.testing import assert_frame_equal
 from geopandas import GeoDataFrame
 from shapely.geometry import Point, LineString
 from datetime import datetime, timedelta
-from fiona.crs import from_epsg
+from pyproj import CRS
 from movingpandas.trajectory import (
     Trajectory,
     DIRECTION_COL_NAME,
@@ -19,11 +19,17 @@ from movingpandas.trajectory import (
 )
 from movingpandas.unit_utils import MissingCRSWarning
 
-from . import requires_holoviews, has_holoviews
+from . import (
+    requires_holoviews,
+    has_holoviews,
+    requires_folium,
+    has_geopandas1,
+    requires_geopandas1,
+)
 
 
-CRS_METRIC = from_epsg(31256)
-CRS_LATLON = from_epsg(4326)
+CRS_METRIC = CRS.from_user_input(31256)
+CRS_LATLON = CRS.from_user_input(4326)
 
 
 def assert_frame_not_equal(*args, **kwargs):
@@ -477,6 +483,19 @@ class TestTrajectory:
         traj.add_speed()
         traj.add_speed(overwrite=True)
 
+    def test_add_speed_with_nanoseconds(self):
+        import numpy as np
+
+        start_time = pd.Timestamp.now() + pd.Timedelta(nanoseconds=10)
+        timedeltas = np.arange(10) * pd.Timedelta(seconds=0.2)
+        timestamps = start_time + timedeltas
+        df = pd.DataFrame({"datetime": timestamps})
+        df["x"] = np.arange(0, 10) * 100
+        df["y"] = np.arange(0, 10) * 100
+        traj = Trajectory(df, traj_id=1, t="datetime", y="y", x="x", crs="epsg:32632")
+        traj.add_speed()
+        assert len(traj.df) == 10
+
     def test_add_acceleration(self):
         traj = make_traj([Node(0, 0), Node(6, 0, second=1), Node(18, 0, second=2)])
         traj.add_acceleration()
@@ -776,6 +795,17 @@ class TestTrajectory:
         plot = self.default_traj_metric.plot()
         assert isinstance(plot, Axes)
 
+    @requires_folium
+    def test_explore_exists(self):
+        from folium.folium import Map
+
+        if has_geopandas1:
+            plot = self.default_traj_metric.explore()
+            assert isinstance(plot, Map)
+        else:
+            with pytest.raises(NotImplementedError):
+                plot = self.default_traj_metric.explore()
+
     @requires_holoviews
     def test_hvplot_exists(self):
         import holoviews
@@ -842,6 +872,13 @@ class TestTrajectory:
         traj.plot(column="speed")
         assert_frame_equal(self.default_traj_metric.df, traj.df)
 
+    @requires_geopandas1
+    @requires_folium
+    def test_explore_does_not_alter_df(self):
+        traj = self.default_traj_metric.copy()
+        traj.explore(column="speed")
+        assert_frame_equal(self.default_traj_metric.df, traj.df)
+
     def test_linestringbetween_does_not_alter_df(self):
         traj = self.default_traj_metric.copy()
         traj.get_linestring_between(
@@ -854,6 +891,14 @@ class TestTrajectory:
         traj.get_position_at(datetime(1970, 1, 1, 0, 0, 2), method="nearest")
         assert_frame_equal(self.default_traj_metric.df, traj.df)
 
+    @requires_geopandas1
+    @requires_folium
+    def test_explore_speed(self):
+        from folium.folium import Map
+
+        result = self.default_traj_metric.explore(column="speed")
+        assert isinstance(result, Map)
+
     @requires_holoviews
     def test_support_for_subclasses_of_point(self):
         df = pd.DataFrame(
@@ -998,6 +1043,20 @@ class TestTrajectory:
 
         assert_frame_equal(traj_gdf_wkt, expected_line_gdf_wkt)
 
+    def test_to_mf_json_tostr(self):
+        json = self.default_traj_metric.to_mf_json()
+        assert (
+            str(json)
+            == """{'type': 'FeatureCollection', 'features': [{'type': 'Feature', 'properties': {'traj_id': 1, 'value': 1}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(0.0, 0.0), (6.0, 0.0), (10.0, 0.0)], 'datetimes': ['1970-01-01 00:00:00', '1970-01-01 00:00:10', '1970-01-01 00:00:20']}}]}"""  # noqa F401
+        )
+
+    def test_to_mf_json(self):
+        json = self.default_traj_metric.to_mf_json(datetime_to_str=False)
+        assert (
+            str(json)
+            == """{'type': 'FeatureCollection', 'features': [{'type': 'Feature', 'properties': {'traj_id': 1, 'value': 1}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(0.0, 0.0), (6.0, 0.0), (10.0, 0.0)], 'datetimes': [Timestamp('1970-01-01 00:00:00'), Timestamp('1970-01-01 00:00:10'), Timestamp('1970-01-01 00:00:20')]}}]}"""  # noqa F401
+        )
+
     def test_error_due_to_wrong_gdf_index(self):
         with pytest.raises(TypeError):
             df = pd.DataFrame(
