@@ -6,7 +6,7 @@ from math import sqrt
 
 import pandas as pd
 import pytest
-from fiona.crs import from_epsg
+from pyproj import CRS
 from geopandas import GeoDataFrame
 from pandas import Timestamp
 from pandas.testing import assert_frame_equal
@@ -22,10 +22,10 @@ from movingpandas.trajectory import (
     TIMEDELTA_COL_NAME,
 )
 from movingpandas.trajectory_collection import TrajectoryCollection
-from . import requires_holoviews
+from . import requires_holoviews, requires_folium, has_geopandas1, requires_geopandas1
 
-CRS_METRIC = from_epsg(31256)
-CRS_LATLON = from_epsg(4326)
+CRS_METRIC = CRS.from_user_input(31256)
+CRS_LATLON = CRS.from_user_input(4326)
 
 
 class TestTrajectoryCollection:
@@ -124,6 +124,7 @@ class TestTrajectoryCollection:
         assert locs.iloc[1].geometry in [Point(0, 0), Point(10, 10)]
         assert locs.iloc[0].geometry != locs.iloc[1].geometry
         assert isinstance(locs, GeoDataFrame)
+        assert locs.crs == CRS_METRIC
 
     def test_timestamp_column_present_in_start_locations(self):
         locs = self.collection.get_start_locations()
@@ -152,6 +153,7 @@ class TestTrajectoryCollection:
         assert locs.iloc[1].geometry in [Point(9, 9), Point(190, 10)]
         assert locs.iloc[0].geometry != locs.iloc[1].geometry
         assert isinstance(locs, GeoDataFrame)
+        assert locs.crs == CRS_METRIC
 
     def test_get_segments_between(self):
         collection = self.collection.get_segments_between(
@@ -196,17 +198,17 @@ class TestTrajectoryCollection:
         assert collection.trajectories[0].to_linestring().wkt == "LINESTRING (0 0, 1 0)"
         assert collection.trajectories[1].to_linestring().wkt == "LINESTRING (6 1, 6 3)"
 
-    """ Fails, related to https://github.com/movingpandas/movingpandas/discussions/235
     def test_clip_with_multipolygon2(self):
-        polygon = MultiPolygon([
-            Polygon([(-1, -1), (-1, 1), (1, 1), (1, -1), (-1, -1)]),
-            Polygon([(3, -1), (3, 1), (4, 1), (4, -1), (3, -1)])
-        ])
+        polygon = MultiPolygon(
+            [
+                Polygon([(-1, -1), (-1, 1), (1, 1), (1, -1), (-1, -1)]),
+                Polygon([(3, -1), (3, 1), (4, 1), (4, -1), (3, -1)]),
+            ]
+        )
         collection = self.collection.clip(polygon)
         assert len(collection) == 2
         assert collection.trajectories[0].to_linestring().wkt == "LINESTRING (0 0, 1 0)"
         assert collection.trajectories[1].to_linestring().wkt == "LINESTRING (3 0, 4 0)"
-    """
 
     def test_clip_with_min_length(self):
         polygon = Polygon([(-1, -1), (-1, 1), (1, 1), (1, -1), (-1, -1)])
@@ -235,6 +237,17 @@ class TestTrajectoryCollection:
         result = self.collection.plot()
         assert isinstance(result, Axes)
 
+    @requires_folium
+    def test_explore_exists(self):
+        from folium.folium import Map
+
+        if has_geopandas1:
+            plot = self.collection.explore()
+            assert isinstance(plot, Map)
+        else:
+            with pytest.raises(NotImplementedError):
+                plot = self.collection.explore()
+
     @requires_holoviews
     def test_hvplot_exists(self):
         import holoviews
@@ -288,6 +301,25 @@ class TestTrajectoryCollection:
             ]
         )
 
+    @requires_geopandas1
+    @requires_folium
+    def test_explore_speed_not_altering_collection(self):
+        self.collection.explore(column="speed")
+        assert all(
+            [
+                "speed" not in traj.df.columns.values
+                for traj in self.collection.trajectories
+            ]
+        )
+
+    @requires_geopandas1
+    @requires_folium
+    def test_explore_speed(self):
+        from folium.folium import Map
+
+        result = self.collection.explore(column="speed")
+        assert isinstance(result, Map)
+
     def test_traj_with_less_than_two_points(self):
         df = pd.DataFrame(
             [[1, "A", Point(0, 0), datetime(2018, 1, 1, 12, 0, 0), 9, "a"]],
@@ -455,16 +487,20 @@ class TestTrajectoryCollection:
         result1 = self.collection.trajectories[1].df[TIMEDELTA_COL_NAME].tolist()
         assert result1 == expected.trajectories[1].df[TIMEDELTA_COL_NAME].tolist()
 
-    def test_to_point_gdf(self):
+    def test_to_point_gdf(self, tmp_path):
         point_gdf = self.collection.to_point_gdf()
-        point_gdf.to_file("temp.gpkg", layer="points", driver="GPKG")
+        gpkg_path = tmp_path / "temp.gpkg"
+        point_gdf.to_file(gpkg_path, layer="points", driver="GPKG")
+        assert gpkg_path.exists()
         assert_frame_equal(point_gdf, self.geo_df)
 
-    def test_to_line_gdf(self):
+    def test_to_line_gdf(self, tmp_path):
         temp_df = self.geo_df.drop(columns=["obj", "val", "val2"])
         tc = TrajectoryCollection(temp_df, "id")
         line_gdf = tc.to_line_gdf()
-        line_gdf.to_file("temp.gpkg", layer="lines", driver="GPKG")
+        gpkg_path = tmp_path / "temp.gpkg"
+        line_gdf.to_file(gpkg_path, layer="lines", driver="GPKG")
+        assert gpkg_path.exists()
         t1 = [
             datetime(2018, 1, 1, 12, 0),
             datetime(2018, 1, 1, 12, 6),
@@ -491,11 +527,13 @@ class TestTrajectoryCollection:
         expected_line_gdf = GeoDataFrame(df2, crs=CRS_METRIC)
         assert_frame_equal(line_gdf, expected_line_gdf)
 
-    def test_to_traj_gdf(self):
+    def test_to_traj_gdf(self, tmp_path):
         temp_df = self.geo_df.drop(columns=["obj", "val", "val2"])
         tc = TrajectoryCollection(temp_df, "id")
         traj_gdf = tc.to_traj_gdf()
-        traj_gdf.to_file("temp.gpkg", layer="trajs", driver="GPKG")
+        gpkg_path = tmp_path / "temp.gpkg"
+        traj_gdf.to_file(gpkg_path, layer="trajs", driver="GPKG")
+        assert gpkg_path.exists()
         rows = [
             {
                 "id": 1,
@@ -558,3 +596,10 @@ class TestTrajectoryCollection:
         expected_line_gdf = GeoDataFrame(df2, crs=CRS_METRIC)
 
         assert_frame_equal(traj_gdf, expected_line_gdf)
+
+    def test_to_mf_json(self):
+        json = self.collection.to_mf_json(datetime_to_str=False)
+        assert (
+            str(json)
+            == """{'type': 'FeatureCollection', 'features': [{'type': 'Feature', 'properties': {'id': 1, 'obj': 'A', 'val': 9, 'val2': 'a'}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(0.0, 0.0), (6.0, 0.0), (6.0, 6.0), (9.0, 9.0)], 'datetimes': [Timestamp('2018-01-01 12:00:00'), Timestamp('2018-01-01 12:06:00'), Timestamp('2018-01-01 14:10:00'), Timestamp('2018-01-01 14:15:00')]}}, {'type': 'Feature', 'properties': {'id': 2, 'obj': 'A', 'val': 10, 'val2': 'e'}, 'temporalGeometry': {'type': 'MovingPoint', 'coordinates': [(10.0, 10.0), (16.0, 10.0), (16.0, 16.0), (190.0, 10.0)], 'datetimes': [Timestamp('2018-01-01 12:00:00'), Timestamp('2018-01-01 12:06:00'), Timestamp('2018-01-02 13:10:00'), Timestamp('2018-01-02 13:15:00')]}}]}"""  # noqa F401
+        )
