@@ -33,6 +33,7 @@ from .unit_utils import (
 )
 from .spatiotemporal_utils import get_speed2
 from .trajectory_plotter import _TrajectoryPlotter
+from .io import gdf_to_mf_json
 
 warnings.filterwarnings(  # see https://github.com/movingpandas/movingpandas/issues/289
     "ignore", message="CRS not set for some of the concatenation inputs."
@@ -93,7 +94,6 @@ class Trajectory:
         >>> import pandas as pd
         >>> import geopandas as gpd
         >>> import movingpandas as mpd
-        >>> from fiona.crs import from_epsg
         >>>
         >>> df = pd.DataFrame([
         ...     {'geometry':Point(0,0), 't':datetime(2018,1,1,12,0,0)},
@@ -101,7 +101,7 @@ class Trajectory:
         ...     {'geometry':Point(6,6), 't':datetime(2018,1,1,12,10,0)},
         ...     {'geometry':Point(9,9), 't':datetime(2018,1,1,12,15,0)}
         ... ]).set_index('t')
-        >>> gdf = gpd.GeoDataFrame(df, crs=from_epsg(31256))
+        >>> gdf = gpd.GeoDataFrame(df, crs=31256)
         >>> traj = mpd.Trajectory(gdf, 1)
 
         For more examples, see the tutorial notebooks_.
@@ -259,6 +259,31 @@ class Trajectory:
         """
         return _TrajectoryPlotter(self, *args, **kwargs).plot()
 
+    def explore(self, *args, **kwargs):
+        """
+        Generate a plot using GeoPandas explore (folium/leaflet.js)
+        https://geopandas.org/en/stable/docs/reference/api/geopandas.GeoDataFrame.explore.html
+
+        Parameters
+        ----------
+        args :
+            These parameters will be passed to GeoPandas explore
+        kwargs :
+            These parameters will be passed to GeoPandas explore
+
+        Returns
+        -------
+        m : folium.folium.Map
+            folium Map instance
+
+        Examples
+        --------
+        Plot speed along trajectory (with legend and specified figure size):
+
+        >>> trajectory.explore(column='speed', vmax=20, tiles="CartoDB positron")
+        """  # noqa: E501
+        return _TrajectoryPlotter(self, *args, **kwargs).explore()
+
     def hvplot(self, *args, **kwargs):
         """
         Generate an interactive plot using HoloViews.
@@ -297,8 +322,8 @@ class Trajectory:
         kwargs :
             These parameters will be passed to the TrajectoryPlotter
 
-            To customize the plots, check the list of supported colormaps_.
-            .. _colormaps: https://holoviews.org/user_guide/Colormaps.html#available-colormaps
+            To customize the plots, check the list of supported colormaps:
+            https://holoviews.org/user_guide/Colormaps.html#available-colormaps
 
         Examples
         --------
@@ -609,6 +634,30 @@ class Trajectory:
         traj_gdf = GeoDataFrame(df, crs=self.crs)
         return traj_gdf
 
+    def to_mf_json(self, datetime_to_str=True, temporal_columns=None):
+        """
+        Converts a Trajectory to a dictionary compatible with the Moving
+        Features JSON (MF-JSON) specification.
+
+        Examples
+        --------
+
+        >>> traj.to_mf_json()
+
+        Returns:
+            dict: The MF-JSON representation of the GeoDataFrame as a dictionary.
+        """
+        tmp = self.to_point_gdf()
+        t = tmp.index.name
+        mf_json = gdf_to_mf_json(
+            tmp.reset_index(),
+            self.get_traj_id_col(),
+            t,
+            datetime_to_str=datetime_to_str,
+            temporal_columns=temporal_columns,
+        )
+        return mf_json
+
     def get_start_location(self):
         """
         Return the trajectory's start location.
@@ -1016,7 +1065,8 @@ class Trajectory:
         self._add_prev_pt()
         self.df[name] = self.df.apply(self._compute_heading, axis=1)
         # set the direction in the first row to the direction of the second row
-        self.df.at[self.get_start_time(), name] = self.df.iloc[1][name]
+        t0 = self.df.index.min().to_datetime64()
+        self.df.at[t0, name] = self.df.iloc[1][name]
         self.df.drop(columns=["prev_pt"], inplace=True)
         return self
 
@@ -1053,7 +1103,8 @@ class Trajectory:
         temp_df["prev_" + direction_col] = temp_df[direction_col].shift()
         self.df[name] = temp_df.apply(self._compute_angular_difference, axis=1)
         # set the first row to be 0
-        self.df.at[self.get_start_time(), name] = 0.0
+        t0 = self.df.index.min().to_datetime64()
+        self.df.at[t0, name] = 0.0
         if not direction_exists:
             self.df.drop(columns=[DIRECTION_COL_NAME], inplace=True)
         return self
@@ -1311,7 +1362,8 @@ class Trajectory:
         except ValueError as e:
             raise e
         # set the distance in the first row to zero
-        temp_df.at[self.get_start_time(), name] = 0
+        t0 = self.df.index.min().to_datetime64()
+        temp_df.at[t0, name] = 0
         temp_df = temp_df.drop(columns=["prev_pt"])
         return temp_df
 
@@ -1325,7 +1377,8 @@ class Trajectory:
         except ValueError as e:
             raise e
         # set the speed in the first row to the speed of the second row
-        temp_df.at[self.get_start_time(), name] = temp_df.iloc[1][name]
+        t0 = self.df.index.min().to_datetime64()
+        temp_df.at[t0, name] = temp_df.iloc[1][name]
         temp_df = temp_df.drop(columns=["prev_pt", "delta_t"])
         return temp_df
 
@@ -1338,7 +1391,8 @@ class Trajectory:
         )
         # set the acceleration in the first row to the acceleration of the
         # second row
-        temp_df.at[self.get_start_time(), name] = temp_df.iloc[1][name]
+        t0 = self.df.index.min().to_datetime64()
+        temp_df.at[t0, name] = temp_df.iloc[1][name]
         return temp_df.drop(columns=["speed_temp"])
 
     def intersects(self, polygon):
@@ -1543,4 +1597,7 @@ class Trajectory:
             The polygon or line (in case of only two points)
             of the Minimum Convex Polygon
         """
-        return self.df.geometry.unary_union.convex_hull
+        try:
+            return self.df.geometry.union_all().convex_hull
+        except AttributeError:
+            return self.df.geometry.unary_union.convex_hull
