@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+import warnings
+
 import pandas as pd
 from pandas.api.types import is_numeric_dtype
 
@@ -62,7 +64,7 @@ class IqrCleaner(TrajectoryCleaner):
     ----------
     columns: dictionary
         Information regarding the columns that will be used to clean the trajectory
-        and the accompanying thresholds. ex. - {'speed': 30, 'heading': 360} etc.
+        and the accompanying thresholds.
 
         Key-value pairs of columns and alpha (IQR multiplier).
         Note: Setting alpha=3 is widely used.
@@ -108,14 +110,10 @@ class OutlierCleaner(TrajectoryCleaner):
 
     Parameters
     ----------
-    v_max: speed threshold
+    v_max : numeric
+        Speed threshold
     units : tuple
         Units in which to calculate speed
-        distance : str
-            Abbreviation for the distance unit
-            (default: CRS units, or metres if geographic)
-        time : str
-            Abbreviation for the time unit (default: seconds)
         For more info, check the list of supported units at
         https://movingpandas.org/units
 
@@ -152,4 +150,14 @@ class OutlierCleaner(TrajectoryCleaner):
             prev = curr
 
         out_traj.df.drop(ixs, inplace=True)
+
+        if not out_traj.is_valid():
+            warnings.warn(
+                f"Cleaning failed for trajectory {out_traj.id} "
+                "due to invalid result (e.g. <2 points remaining). "
+                "Returning original trajectory.",
+                UserWarning,
+            )
+            out_traj = traj.copy()
+
         return out_traj
