@@ -14,6 +14,7 @@ from .trajectory import (
 )
 from .trajectory_plotter import _TrajectoryPlotter
 from .unit_utils import UNITS
+from .io import gdf_to_mf_json
 
 
 @staticmethod
@@ -179,6 +180,30 @@ class TrajectoryCollection:
         gdf.reset_index(drop=True, inplace=True)
         return gdf
 
+    def to_mf_json(self, datetime_to_str=True, temporal_columns=None):
+        """
+        Converts a TrajectoryCollection to a dictionary compatible with the Moving
+        Features JSON (MF-JSON) specification.
+
+        Examples
+        --------
+
+        >>> tc.to_mf_json()
+
+        Returns:
+            dict: The MF-JSON representation of the GeoDataFrame as a dictionary.
+        """
+        tmp = self.to_point_gdf()
+        t = tmp.index.name
+        mf_json = gdf_to_mf_json(
+            tmp.reset_index(),
+            self.get_traj_id_col(),
+            t,
+            datetime_to_str=datetime_to_str,
+            temporal_columns=temporal_columns,
+        )
+        return mf_json
+
     def _df_to_trajectories(self, df, traj_id_col, obj_id_col, t, x, y, crs):
         trajectories = []
         for traj_id, values in df.groupby(traj_id_col):
@@ -360,9 +385,11 @@ class TrajectoryCollection:
             df.reset_index(inplace=True)
             df.rename(columns={"index": t}, inplace=True)
 
-            return GeoDataFrame(df)
+            gdf = GeoDataFrame(df)
+            gdf.set_crs(self.get_crs(), inplace=True)
         else:
-            return GeoDataFrame()
+            gdf = GeoDataFrame()
+        return gdf
 
     def get_start_locations(self, with_direction=False):
         """
@@ -752,9 +779,9 @@ class TrajectoryCollection:
             Number of threads to use for computation (default: 1)
         """
         if n_threads <= 1:
-            self._add_distance(self.trajectories, name, UNITS(), overwrite)
+            self._add_timedelta(self.trajectories, name, UNITS(), overwrite)
         else:
-            self._multithread(self._add_distance, n_threads, name, UNITS(), overwrite)
+            self._multithread(self._add_timedelta, n_threads, name, UNITS(), overwrite)
         return self
 
     def _add_timedelta(self, trajs, name, units, overwrite):
@@ -830,6 +857,31 @@ class TrajectoryCollection:
         """
         return _TrajectoryPlotter(self, *args, **kwargs).plot()
 
+    def explore(self, *args, **kwargs):
+        """
+        Generate a plot using GeoPandas explore (folium/leaflet.js)
+        https://geopandas.org/en/stable/docs/reference/api/geopandas.GeoDataFrame.explore.html
+
+        Parameters
+        ----------
+        args :
+            These parameters will be passed to GeoPandas explore
+        kwargs :
+            These parameters will be passed to GeoPandas explore
+
+        Returns
+        -------
+        m : folium.folium.Map
+            folium Map instance
+
+        Examples
+        --------
+        Plot speed along trajectory (with legend and specified figure size):
+
+        >>> trajectory_collection.explore(column='speed', vmax=20, tiles="CartoDB positron")
+        """  # noqa: E501
+        return _TrajectoryPlotter(self, *args, **kwargs).explore()
+
     def hvplot(self, *args, **kwargs):
         """
         Generate an interactive trajectory plot.
@@ -841,8 +893,8 @@ class TrajectoryCollection:
         kwargs :
             These parameters will be passed to the TrajectoryPlotter
 
-            To customize the plots, check the list of supported colormaps_.
-            .. _colormaps: https://holoviews.org/user_guide/Colormaps.html#available-colormaps
+            To customize the plots, check the list of supported colormaps:
+            https://holoviews.org/user_guide/Colormaps.html#available-colormaps
 
         Examples
         --------
@@ -868,8 +920,8 @@ class TrajectoryCollection:
         kwargs :
             These parameters will be passed to the TrajectoryPlotter
 
-            To customize the plots, check the list of supported colormaps_.
-            .. _colormaps: https://holoviews.org/user_guide/Colormaps.html#available-colormaps
+            To customize the plots, check the list of supported colormaps:
+            https://holoviews.org/user_guide/Colormaps.html#available-colormaps
 
         Examples
         --------
