@@ -2,7 +2,9 @@
 
 from copy import copy
 from pandas import Grouper
+from geopandas import GeoDataFrame
 import numpy as np
+import warnings
 
 from .trajectory_stop_detector import TrajectoryStopDetector
 from .trajectory import Trajectory
@@ -81,18 +83,33 @@ class TemporalSplitter(TrajectorySplitter):
 
     def _split_traj(self, traj, mode="day", min_length=0):
         result = []
-        modes = {"hour": "H", "day": "D", "month": "M", "year": "Y"}
+        modes = {"hour": "h", "day": "D", "month": "ME", "year": "YE"}
         if mode in modes.keys():
             mode = modes[mode]
         grouped = traj.df.groupby(Grouper(freq=mode))
-        for key, values in grouped:
-            if len(values) > 1:
+        dfs = []
+        show_warning = False
+        for _, values in grouped:
+            if len(values) == 0:
+                show_warning = True
+            else:
+                dfs.append(values)
+        if show_warning:
+            warnings.warn(
+                f"Temporal splitting results contain observation gaps that exceed your "
+                f"split size of {mode}. Consider running the ObservationGapSplitter to "
+                f"further clean the results."
+            )
+
+        for i, df in enumerate(dfs):
+            if i < len(dfs) - 1:
+                next_index = dfs[i + 1].iloc[0].name
+                next_values = dfs[i + 1].iloc[0].to_dict()
+                df.loc[next_index] = next_values
+                df = df.sort_index(ascending=True)
+            if len(df) > 1:
                 result.append(
-                    Trajectory(
-                        values,
-                        f"{traj.id}_{key}",
-                        traj_id_col=traj.get_traj_id_col(),
-                    )
+                    Trajectory(df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col())
                 )
         return TrajectoryCollection(result, min_length=min_length)
 
@@ -264,10 +281,10 @@ class AngleChangeSplitter(TrajectorySplitter):
         for i, df in enumerate(dfs):
             df = df.drop(columns=["dirChange"])
             if len(df) > 1:
-                prev_i = dfs[i - 1].iloc[-1].name
-                prev_d = dfs[i - 1].iloc[-1].to_dict()
+                prev_index = dfs[i - 1].iloc[-1].name
+                prev_values = dfs[i - 1].iloc[-1].to_dict()
                 if i > 0:
-                    df.loc[prev_i] = prev_d
+                    df.loc[prev_index] = prev_values
                     df = df.sort_index(ascending=True)
 
                 result.append(
@@ -275,3 +292,46 @@ class AngleChangeSplitter(TrajectorySplitter):
                 )
 
         return TrajectoryCollection(result, min_length=min_length)
+
+
+class ValueChangeSplitter(TrajectorySplitter):
+    """
+    Split trajectories into subtrajectories whenever there is a change in
+    the specified column values.
+
+    Parameters
+    ----------
+    col_name : string
+        Name of the col to monitor for changes in consecutive values
+    min_length : numeric
+        Desired minimum length of trajectories. Shorter trajectories are discarded.
+        (Length is calculated using CRS units, except if the CRS is geographic
+        (e.g. EPSG:4326 WGS84) then length is calculated in metres.)
+
+    Examples
+    --------
+
+    >>> mpd.ValueChangeSplitter(traj).split(col_name='column1')
+    """
+
+    def _split_traj(self, traj, col_name, min_length=0):
+        result = []
+        temp_df = traj.df.copy()
+        temp_df["t"] = temp_df.index
+        temp_df["change"] = temp_df[col_name].shift() != temp_df[col_name]
+        temp_df["change"] = temp_df["change"].apply(lambda x: 1 if x else 0).cumsum()
+        dfs = [group[1] for group in temp_df.groupby(temp_df["change"])]
+        for i, df in enumerate(dfs):
+            df = df.drop(columns=["t", "change"])
+            if i < (len(dfs) - 1):
+                next_index = dfs[i + 1].iloc[0].name
+                next_values = dfs[i + 1].iloc[0].to_dict()
+                df.loc[next_index] = next_values
+                df = df.sort_index(ascending=True)
+            if len(df) > 1:
+                df = GeoDataFrame(df).set_crs(traj.df.crs)
+                traj = Trajectory(
+                    df, f"{traj.id}_{i}", traj_id_col=traj.get_traj_id_col()
+                )
+                result.append(traj)
+        return TrajectoryCollection(result, min_length=min_length)
